@@ -423,6 +423,7 @@ def run_tests(tests_root, metadata_root, prefs_root, test_types, binary=None,
               total_chunks=1, this_chunk=1, timeout_multiplier=1,
               repeat=1, **kwargs):
     logging_queue = None
+    loggging_thread = None
     original_stdio = (sys.stdout, sys.stderr)
     test_queues = None
 
@@ -501,7 +502,8 @@ def run_tests(tests_root, metadata_root, prefs_root, test_types, binary=None,
         if capture_stdio and logging_queue is not None:
             logger.info("Closing logging queue")
             logging_queue.put(None)
-            logging_thread.join(10)
+            if logging_thread is not None:
+                logging_thread.join(10)
             logging_queue.close()
 
     return manager_group.unexpected_count() == 0
